/**** docbook.css embedded ****/
.formalpara-title, span.msgmain-title, span.msgsub-title, span.msgrel-title, span.msglevel-title, span.msgorig-title, span.msgaud-title, span.msgexplan-title {
  font-weight: bold;
}

div.blockquote-title {
  font-weight: bold;
  margin-top: 1em;
  margin-bottom: 1em;
}

div.msglevel, div.msgorig, div.msgaud, div.msgexplan {
  margin-top: 1em;
  margin-bottom: 1em;
}

div.screen, div.programlisting, div.synopsis {
  white-space: pre;
  font-family: monospace;
}

div.figure-title, div.example-title, div.equation-title, div.table-title, div.sidebar-title {
  font-weight: bold;
}

/**** Specific to TDAH ****/

/* Styles of sidebars */
hr.delimit-sidebar {
    /* Those horizantal rules are for the Kindle only */
    display: none;
}

div.sidebar {
    border: 2px solid #aaaaaa;
    margin-top: 10px;
    margin-bottom: 10px;
    padding: 10px;
    font-size: 90%;
    background-color: #eeeeee;
}

div.sidebar-title {
    border-bottom: 1px solid black;
    font-weight: bold;
}

/* Styles of block URLs */
div.url {
    margin-top: 0.5em;
}
div.url + div.url {
    margin-top: 0;
}

/* Styles for Kindle's Mobipocket (e-ink reader) */
@media amzn-mobi {
    hr.delimit-sidebar {
	display: block;
    }
    div.sidebar {
	border-left: 1px solid black;
	margin-left: 5%;
	padding: 5px;
    }
    div.sidebar-title {
	border-bottom: 0px;
	text-align: center;
	text-indent: 0;
    }
    p {
	text-indent: 0;
	margin-top: 0.5em;
    }
    p.title {
	margin-top: 0;
    }
    div.section {
	margin-top: 0.5em;
    }
}
