a:link {
	color:#0035C7;
}

a:visited {
	color:#54638C;
}

h1 {
	color:#C70036;
}

div.producttitle {
	color:#C70036;
}

.section h1.title {
	color:#C70036;
}


h2,h3,h4,h5,h6 {
	color:#C70036;
}

.docnav.top li.home {
        color: #C70036;
}


table {
	border:1px solid #aaa;
}

table th {
	background-color:#900;
}

table tr.even td {
	background-color:#f5f5f5;
}

#title a {
	height:54px;
}

.term{
	color:#C70036;
}

.revhistory table th {
	color:#C70036;
}

.titlepage .edition {
	color: #C70036;
}

span.remark{
	background-color: #ffff00;
}

/* Styles of block URLs */
div.url {
    margin-top: 0.5em;
}
div.url + div.url {
    margin-top: 0;
}

/* Styles of sidebars */
div.sidebar {
    border: 2px solid #aaaaaa;
    margin-top: 10px;
    margin-bottom: 10px;
    padding: 10px;
    font-size: 90%;
    background-color: #eeeeee;
}

div.sidebar > div.titlepage {
    border-bottom: 1px solid;
}

div.sidebar > div.titlepage span.emphasis:nth-child(1) > em {
    color: #666666;
    font-style: normal;
    font-variant: small-caps;
}

/* Modify behaviour within sidebars */
div.sidebar p.title {
    margin-bottom: 0;
    margin-top: 0;
}

div.sidebar > p, div.sidebar > div.para {
    margin-top: 1em;
    margin-bottom: 0;
}

/* Styles of screens */
.screen .computeroutput {
    font-weight: normal;
}

/* CSS for the banner */
#banner {
    position: fixed;
    top: 0;
    right: 0;
    z-index: 2;
}
#banner a {
    display: block;
    font-size: 13px;
    font-family: "DejaVu Sans Condensed", "Liberation Sans", "Nimbus Sans L", Tahoma, Geneva, "Helvetica Neue", Helvetica, Arial, sans serif;
    font-weight: bold;
    text-decoration: none;
    text-shadow: 0 0 0.5em #444;
    border-bottom: none;

    background-color: #9a0000;
    color: #FFF;
    text-align: center;
    box-shadow: 0 0 13px #888;
}
#banner .text {
    display: block;
    padding: 3px 0;
    border: 1px solid #bf6060;
}
#banner a:hover {
    color: #ffff99;
}

@media (min-width: 1000px) {
    #banner {
	height: 149px;
	width: 149px;
	overflow: hidden;
	padding: 0;
	margin: 0;
    }
    #banner a {
	width: 190px;
	padding: 1px 15px 1px 25px;
	position: relative;
	left: 20px;
	top: -37px;

	-moz-transform-origin: 0 0 ;
	-moz-transform: rotate(45deg);
	-moz-box-shadow: 0 0 13px #888;

	-webkit-transform-origin: 0 0 ;
	-webkit-transform: rotate(45deg);
	-webkit-box-shadow: 0 0 13px #888;

	-ms-transform-origin: 0 0 ;
	-ms-transform: rotate(45deg);
	-ms-box-shadow: 0 0 13px #888;

	transform-origin: 0 0 ;
	transform: rotate(45deg);
	box-shadow: 0 0 13px #888;
    }
}
@media (max-width: 999px) {
    #banner {
	width: 100%;
	position: fixed;
	top: 0;
	left: 0;
    }
    #title {
	padding-top: 20px;
    }
}
